/* SPDX-FileCopyrightText: 2025 - Sébastien Wilmet
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#pragma once

#include <libpeas/peas.h>

G_BEGIN_DECLS

G_MODULE_EXPORT
void peas_register_types (PeasObjectModule *module);

G_END_DECLS
